##  Individually Reviewing and Creating Fact Sheets and Relations
  1. Chose a fact sheet to open the right-side panel.
  2. Review the proposed fact sheets and relations. While reviewing, you can make the following changes:
     * Link the discovered fact sheet to a different fact sheet than the suggested one: Hover over the suggested fact sheet, choose Edit, then search for and select an alternative fact sheet.
     * Reject a relation: Uncheck the check box against the relation you want to avoid creating.
     * Modify the target fact sheet of a relation: Hover over the suggested target fact sheet on the right, choose Edit, then search for and select a different fact sheet.
![LeanIX interface showing suggested fact sheets and relation options for review and editing.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio65bc1654187a498d9f42f5feaa02b7ad_LowRes.png)
  3. Choose Confirm at the bottom to create the fact sheets and relations.
